"""
Criado por Érick Ghuron

Jupiterweb API
"""

__author__ = 'Erick Ghuron'
__version__ = '1.4.2'

from jupiterweb.api import JupiterWeb
